..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Changes
=======

Version 1.2.0a2 (released 2020-06-02)

- Integrates Semantic-UI templates
- Removes example app

Version 1.1.1 (released 2020-05-11)

- Minimum version of Invenio-Accounts bumped to v1.2.1 due WTForms moving the
  email validation to an optional dependency

Version 1.1.0 (released 2020-03-11)

- Change Flask dependency management to invenio-base
- drop Python 2.7 support

Version 1.0.1 (released 2018-05-25)

- Flask v1.0 support.

Version 1.0.0 (released 2018-03-23)

- Initial public release.
